# EMEPy 1.0.0 Eigenmode Expansion Tool for Python

<p align="center">
    <img src="docs/images/logo.png" alt="drawing" width="500"/>
</p>



### An open source tool for simulating EM fields in python using the Eigenmode Expansion Method (EME). Employs neural networks as a means for accelerating the cross sectional field profile generation process.

## Installation

Install the development version of emepy using pip:

    pip install -e .

Or collect the most recent publication to pip

    pip install emepy

## Docs

Read the docs [here](https://emepy.readthedocs.io/en/latest/).

## BibTeX citation

    @misc{hammond_emepy_2020,
        title={emepy},
        author={Ian M. Hammond},
        year={2020},
        publisher={GitHub},
        howpublished={{https://github.com/BYUCamachoLab/emepy}}
    }
